// File generated from our OpenAPI spec

declare module 'stripe' {
  namespace Stripe {
    type DeletedExternalAccount = DeletedBankAccount | DeletedCard;

    type ExternalAccount = BankAccount | Card;
  }
}
