// File generated from our OpenAPI spec

declare module 'stripe' {
  namespace Stripe {
    type CustomerSource = Account | BankAccount | Card | Source;

    type DeletedCustomerSource = DeletedBankAccount | DeletedCard;
  }
}
